
# 📷 Image Processor Package

Pacote Python para **processamento e análise de imagens**, com funcionalidades para leitura, salvamento, redimensionamento, comparação por similaridade, ajuste de histograma e visualização gráfica.

---

## ✨ Funcionalidades

- ✅ Leitura e salvamento de imagens (`.jpg`, `.png`, etc.)
- ✅ Conversão para escala de cinza
- ✅ Comparação de similaridade entre imagens (SSIM)
- ✅ Ajuste de histograma entre imagens
- ✅ Redimensionamento com suavização
- ✅ Visualização com gráficos e histogramas

---

## 📦 Instalação

```bash
pip install image-processor-package
```

> **Requisitos**: Python 3.8+

---

## 🧠 Estrutura do Projeto

```
image_processor_package/
├── main.py
├── processing/
│   ├── compilation.py        # Funções de comparação e histograma
│   └── transformation.py     # Funções de redimensionamento
├── utils/
│   ├── io.py                 # Leitura e salvamento de imagem
│   └── visualization.py      # Funções de plotagem
```

---

## 🧪 Exemplo de Uso

```python
from processing.compilation import find_diference, match_histogram
from processing.transformation import resize_image
from utils.io import read_image, save_image
from utils.visualization import plot_result

image1 = read_image("caminho/para/imagem1.jpg")
image2 = read_image("caminho/para/imagem2.jpg")

image1_resized = resize_image(0.5, image1)
image2_resized = resize_image(0.5, image2)

image2_adjusted = match_histogram(image1_resized, image2_resized)
diferenca = find_diference(image1_resized, image2_adjusted)

plot_result(image1_resized, image2_adjusted, diferenca)
```

---

## 👨‍💻 Autor

**João Pedro Fialho Lopes**  
📧 [jotabelde@gmail.com](mailto:jotabelde@gmail.com)  
🔗 [LinkedIn](https://www.linkedin.com/in/joaopedrofialho)  
📁 [GitHub](https://github.com/Jotabelde)

---

## 📝 Licença

Este projeto está licenciado sob os termos da **MIT License**.
